@@ -12,7 +12,7 @@ use Monitoring::Livestatus::MULTI;
 use Encode;
 use JSON::XS;
 
-our $VERSION = '0.60';
+our $VERSION = '0.72';
 
 
 =head1 NAME
@@ -855,6 +855,14 @@ sub _send {
                 $header .= "KeepAlive: on\n";
             }
         }
+
+        # add additional headers
+        if(defined $opt->{'header'} and ref $opt->{'header'} eq 'HASH') {
+            for my $key ( keys %{$opt->{'header'}}) {
+                $header .= $key.": ".$opt->{'header'}->{$key}."\n";
+            }
+        }
+
         chomp($statement);
         my $send = "$statement\n$header";
         $self->{'logger'}->debug("> ".Dumper($send)) if $self->{'verbose'};
@@ -1126,11 +1134,7 @@ sub _send_socket_do {
     utf8::decode($statement);
     print $sock encode('utf-8' => $statement) or return($self->_socket_error($statement, $sock, 'write to socket failed: '.$!));
 
-    if($self->{'keepalive'}) {
-        print $sock "\n";
-    } else {
-        $sock->shutdown(1) or croak("shutdown failed: $!");
-    }
+    print $sock "\n";
 
     # COMMAND statements never return something
     if($statement =~ m/^COMMAND/mx) {
@@ -1457,6 +1461,7 @@ sub _lowercase_and_verify_options {
         'backend'       => 1,
         'columns'       => 1,
         'deepcopy'      => 1,
+        'header'        => 1,
         'limit'         => 1,
         'limit_start'   => 1,
         'limit_length'  => 1,
